@@ -1,7 +1,14 @@
+from __future__ import annotations
+
 import matplotlib as mpl
 
 
-def generate_style(foreground, background, cycle):
+def generate_style(
+    foreground: str,
+    background: str,
+    comment: str,
+    cycle: list[str],
+) -> dict:
     return {
         "lines.color": foreground,
         "patch.edgecolor": foreground,
@@ -12,7 +19,7 @@ def generate_style(foreground, background, cycle):
         "xtick.color": foreground,
         "ytick.color": foreground,
         "legend.framealpha": 0,
-        "grid.color": foreground,
+        "grid.color": comment,
         "figure.facecolor": background,
         "figure.edgecolor": background,
         "savefig.facecolor": background,
